class SilkError(Exception): ...


def decode(src: bytes, sample_rate: int, frame_size: int = 0, frames_per_packet: int = 1,
           more_internal_decoder_frames: int = 0, in_band_fec_offset: int = 0, loss: bool = False) -> bytes: ...


def encode(input: bytes, sample_rate: int, bit_rate: int, packet_loss_percentage: int = 0, complexity: int = 2,
           use_inband_fec: bool = False, use_dtx: bool = False, tencent: bool = True) -> bytes: ...
